@@ -24,9 +24,6 @@ class SentryClient(object):
     def process(self, **kwargs):
         from sentry.helpers import get_filters
 
-        for filter_ in get_filters():
-            kwargs = filter_(None).process(kwargs) or kwargs
-
         kwargs.setdefault('level', logging.ERROR)
         kwargs.setdefault('server_name', settings.NAME)
 
@@ -38,13 +35,20 @@ class SentryClient(object):
             if not added and cache.incr(cache_key) > settings.THRASHING_LIMIT:
                 return
 
+        for filter_ in get_filters():
+            kwargs = filter_(None).process(kwargs) or kwargs
+        
+        # Make sure all additional data is coerced
+        if 'data' in kwargs:
+            kwargs['data'] = transform(kwargs['data'])
+
         return self.send(**kwargs)
 
     def send(self, **kwargs):
         if settings.REMOTE_URL:
             for url in settings.REMOTE_URL:
                 data = {
-                    'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
+                    'data': base64.b64encode(pickle.dumps(kwargs).encode('zlib')),
                     'key': settings.KEY,
                 }
                 req = urllib2.Request(url, urllib.urlencode(data))
@@ -119,8 +123,8 @@ class SentryClient(object):
         def shorten(var):
             if not isinstance(var, basestring):
                 var = to_unicode(var)
-            if len(var) > 500:
-                var = var[:500] + '...'
+            if len(var) > 200:
+                var = var[:200] + '...'
             return var
 
         reporter = ExceptionReporter(None, exc_type, exc_value, exc_traceback)
